@@ -38,6 +38,7 @@ extern int RXAFSCB_ExecuteRequest(struct rx_call *z_call);
 extern int RXSTATS_ExecuteRequest(struct rx_call *z_call);
 
 extern afs_int32 cryptall;
+extern int cm_enableServerLocks;
 
 osi_log_t *afsd_logp;
 
@@ -66,6 +67,7 @@ int logReady = 0;
 
 char cm_HostName[200];
 long cm_HostAddr;
+unsigned short cm_callbackport = CM_DEFAULT_CALLBACKPORT;
 
 char cm_NetbiosName[MAX_NB_NAME_LENGTH] = "";
 
@@ -852,8 +854,8 @@ int afsd_InitCM(char **reasonP)
     if (code != ERROR_SUCCESS || !buf[0]) {
 #if defined(_IA64_)
         StringCbCopyA(buf, sizeof(buf), "ia64_win64");
-#elif defined(_AMD64)
-        StringCbCopyA(buf, sizeof(buf), "amd64_win64");
+#elif defined(_AMD64_)
+        StringCbCopyA(buf, sizeof(buf), "amd64_win64 x86_win32 i386_w2k");
 #else /* assume x86 32-bit */
         StringCbCopyA(buf, sizeof(buf), "x86_win32 i386_w2k i386_nt40");
 #endif
@@ -920,7 +922,7 @@ int afsd_InitCM(char **reasonP)
                   cm_freelanceEnabled ? "is" : "is not");
     }       
     else {
-        cm_freelanceEnabled = 0;  /* default off */
+        cm_freelanceEnabled = 1;  /* default on */
     }
 #endif /* AFS_FREELANCE_CLIENT */
 
@@ -1047,6 +1049,32 @@ int afsd_InitCM(char **reasonP)
 	cm_daemonTokenCheckInterval = dwValue;
     afsi_log("daemonCheckTokenInterval is %d", cm_daemonTokenCheckInterval);
 
+    dummyLen = sizeof(DWORD);
+    code = RegQueryValueEx(parmKey, "CallBackPort", NULL, NULL,
+                           (BYTE *) &dwValue, &dummyLen);
+    if (code == ERROR_SUCCESS) {
+        cm_callbackport = (unsigned short) dwValue;
+    }
+    afsi_log("CM CallBackPort is %u", cm_callbackport);
+
+    dummyLen = sizeof(DWORD);
+    code = RegQueryValueEx(parmKey, "EnableServerLocks", NULL, NULL,
+                           (BYTE *) &dwValue, &dummyLen);
+    if (code == ERROR_SUCCESS) {
+        cm_enableServerLocks = (unsigned short) dwValue;
+    } 
+    switch (cm_enableServerLocks) {
+    case 0:
+	afsi_log("EnableServerLocks: never");
+    	break;
+    case 2:
+	afsi_log("EnableServerLocks: always");
+	break;
+    case 1:
+    default:
+	afsi_log("EnableServerLocks: server requested");
+    	break;
+    }
     RegCloseKey (parmKey);
 
     /* Call lanahelper to get Netbios name, lan adapter number and gateway flag */
@@ -1137,13 +1165,17 @@ int afsd_InitCM(char **reasonP)
         afsi_log("rx_SetMaxMTU %d successful", rx_mtu);
     }
 
-    /* initialize RX, and tell it to listen to port 7001, which is used for
-     * callback RPC messages.
+    /* initialize RX, and tell it to listen to the callbackport, 
+     * which is used for callback RPC messages.
      */
-    code = rx_Init(htons(7001));
+    code = rx_Init(htons(cm_callbackport));
+    if (code != 0) {
+	afsi_log("rx_Init code %x - retrying with a random port number", code);
+	code = rx_Init(0);
+    }
     afsi_log("rx_Init code %x", code);
     if (code != 0) {
-        *reasonP = "afsd: failed to init rx client on port 7001";
+        *reasonP = "afsd: failed to init rx client";
         return -1;
     }
 
@@ -1222,11 +1254,15 @@ int afsd_InitDaemons(char **reasonP)
     /* this should really be in an init daemon from here on down */
 
     if (!cm_freelanceEnabled) {
+	int attempts = 10;
+
         osi_Log0(afsd_logp, "Loading Root Volume from cell");
-        code = cm_GetVolumeByName(cm_data.rootCellp, cm_rootVolumeName, cm_rootUserp,
-                                  &req, CM_FLAG_CREATE, &cm_data.rootVolumep);
-        afsi_log("cm_GetVolumeByName code %x root vol %x", code,
-                 (code ? (cm_volume_t *)-1 : cm_data.rootVolumep));
+	do {
+	    code = cm_GetVolumeByName(cm_data.rootCellp, cm_rootVolumeName, cm_rootUserp,
+				       &req, CM_FLAG_CREATE, &cm_data.rootVolumep);
+	    afsi_log("cm_GetVolumeByName code %x root vol %x", code,
+		      (code ? (cm_volume_t *)-1 : cm_data.rootVolumep));
+	} while (code && --attempts);
         if (code != 0) {
             *reasonP = "can't find root volume in root cell";
             return -1;
@@ -1519,7 +1555,7 @@ GenerateMiniDump(PEXCEPTION_POINTERS ep)
             DWORD dummyLen;
             DWORD dwValue;
             DWORD code;
-            DWORD dwMiniDumpType = MiniDumpNormal;
+            DWORD dwMiniDumpType = MiniDumpWithDataSegs;
 
             code = RegOpenKeyEx(HKEY_LOCAL_MACHINE, AFSREG_CLT_OPENAFS_SUBKEY,
                                  0, KEY_QUERY_VALUE, &parmKey);
@@ -1528,7 +1564,7 @@ GenerateMiniDump(PEXCEPTION_POINTERS ep)
                 code = RegQueryValueEx(parmKey, "MiniDumpType", NULL, NULL,
                                         (BYTE *) &dwValue, &dummyLen);
                 if (code == ERROR_SUCCESS)
-                    dwMiniDumpType = dwValue ? 1 : 0;
+                    dwMiniDumpType = dwValue;
                 RegCloseKey (parmKey);
             }
 
