@@ -83,6 +83,7 @@ void smb_InitIoctl(void)
         smb_ioctlProcsp[VIOCGETOWNER] = cm_IoctlGetOwner;
         smb_ioctlProcsp[VIOC_RXSTAT_PROC] = cm_IoctlRxStatProcess;
         smb_ioctlProcsp[VIOC_RXSTAT_PEER] = cm_IoctlRxStatPeer;
+        smb_ioctlProcsp[VIOC_UUIDCTL] = cm_IoctlUUIDControl;
 }
 
 /* called to make a fid structure into an IOCTL fid structure */
@@ -116,7 +117,7 @@ void smb_SetupIoctlFid(smb_fid_t *fidp, cm_space_t *prefix)
 smb_IoctlPrepareRead(smb_fid_t *fidp, smb_ioctl_t *ioctlp, cm_user_t *userp)
 {
     long opcode;
-    smb_ioctlProc_t *procp;
+    smb_ioctlProc_t *procp = NULL;
     long code;
 
     if (ioctlp->flags & SMB_IOCTLFLAG_DATAIN) {
@@ -137,7 +138,11 @@ smb_IoctlPrepareRead(smb_fid_t *fidp, smb_ioctl_t *ioctlp, cm_user_t *userp)
             return CM_ERROR_TOOBIG;
 
         /* check for no such proc */
-        procp = smb_ioctlProcsp[opcode];
+	if (fidp->flags & SMB_FID_IOCTL)
+	    procp = smb_ioctlProcsp[opcode];
+	else
+	    procp = NULL;
+
         if (procp == NULL) 
             return CM_ERROR_BADOP;
 
@@ -276,6 +281,51 @@ done:
         return code;
 }
 
+/* called from smb_ReceiveV3WriteX when we receive a write call on the IOCTL
+ * file descriptor.
+ */
+long smb_IoctlV3Write(smb_fid_t *fidp, smb_vc_t *vcp, smb_packet_t *inp, smb_packet_t *outp)
+{
+	smb_ioctl_t *iop;
+        long count;
+        long code;
+        char *op;
+        int inDataBlockCount;
+
+	code = 0;
+	count = smb_GetSMBParm(inp, 10);
+        iop = fidp->ioctlp;
+        
+	smb_IoctlPrepareWrite(fidp, iop);
+
+        op = inp->data + smb_GetSMBParm(inp, 11);
+        inDataBlockCount = count;
+	
+        if (count + iop->inCopied > SMB_IOCTL_MAXDATA) {
+		code = CM_ERROR_TOOBIG;
+                goto done;
+        }
+        
+	/* copy data */
+        memcpy(iop->inDatap + iop->inCopied, op, count);
+        
+        /* adjust counts */
+        iop->inCopied += count;
+
+done:
+	/* return # of bytes written */
+	if (code == 0) {
+		smb_SetSMBParm(outp, 2, count);
+                smb_SetSMBParm(outp, 3, 0); /* reserved */
+	        smb_SetSMBParm(outp, 4, 0); /* reserved */
+	        smb_SetSMBParm(outp, 5, 0); /* reserved */
+	        smb_SetSMBDataLength(outp, 0);
+        }
+
+        return code;
+}
+
+
 /* called from V3 read to handle IOCTL descriptor reads */
 long smb_IoctlV3Read(smb_fid_t *fidp, smb_vc_t *vcp, smb_packet_t *inp, smb_packet_t *outp)
 {
