@@ -16,7 +16,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_util.c,v 1.28.2.1 2006/06/01 15:49:56 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/afs_util.c,v 1.28.2.2 2006/06/15 15:45:19 shadow Exp $");
 
 #include "afs/stds.h"
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
@@ -601,13 +601,13 @@ AFS_MD5_Update (struct afs_md5 *m, const void *v, size_t len)
 	if(offset == 64){
 #if defined(AFSBIG_ENDIAN)
 	    int i;
-	    afs_uint32 current[16];
+	    afs_uint32 temp[16];
 	    struct x32 *us = (struct x32*)m->save;
 	    for(i = 0; i < 8; i++){
-		current[2*i+0] = swap_u_int32_t(us[i].a);
-		current[2*i+1] = swap_u_int32_t(us[i].b);
+		temp[2*i+0] = swap_u_int32_t(us[i].a);
+		temp[2*i+1] = swap_u_int32_t(us[i].b);
 	    }
-	    calc(m, current);
+	    calc(m, temp);
 #else
 	    calc(m, (afs_uint32*)m->save);
 #endif
