@@ -23,7 +23,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/ptserver/pts.c,v 1.12 2004/04/18 03:16:14 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/ptserver/pts.c,v 1.15 2006/03/13 23:15:44 rees Exp $");
 
 #include <stdio.h>
 #include <string.h>
@@ -73,24 +73,21 @@ struct sourcestack {
 } *shead;
 
 int
-Interactive(as)
-     register struct cmd_syndesc *as;
+Interactive(struct cmd_syndesc *as, char *arock)
 {
     finished = 0;
     return 0;
 }
 
 int
-Quit(as)
-     register struct cmd_syndesc *as;
+Quit(struct cmd_syndesc *as, char *arock)
 {
     finished = 1;
     return 0;
 }
 
 int
-Source(as)
-     register struct cmd_syndesc *as;
+Source(struct cmd_syndesc *as, char *arock)
 {
     FILE *fd;
     struct sourcestack *sp;
@@ -118,8 +115,7 @@ Source(as)
 }
 
 int
-Sleep(as)
-     register struct cmd_syndesc *as;
+Sleep(struct cmd_syndesc *as, char *arock)
 {
     int delay;
     if (!as->parms[0].items) {
@@ -157,8 +153,7 @@ osi_audit()
 }
 
 int
-GetGlobals(as)
-     register struct cmd_syndesc *as;
+GetGlobals(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     char *cell;
@@ -190,8 +185,7 @@ GetGlobals(as)
 }
 
 int
-CleanUp(as)
-     register struct cmd_syndesc *as;
+CleanUp(struct cmd_syndesc *as, char *arock)
 {
 #if defined(SUPERGROUPS)
     if (as && !strcmp(as->name, "help"))
@@ -212,8 +206,8 @@ CleanUp(as)
     return 0;
 }
 
-CreateGroup(as)
-     register struct cmd_syndesc *as;
+int
+CreateGroup(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     afs_int32 id;
@@ -272,8 +266,8 @@ CreateGroup(as)
     return 0;
 }
 
-CreateUser(as)
-     register struct cmd_syndesc *as;
+int
+CreateUser(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     afs_int32 id;
@@ -319,10 +313,7 @@ CreateUser(as)
 
 #ifdef notdef
 int
-GetNameOrId(as, lids, lnames)
-     register struct cmd_syndesc *as;
-     struct idlist *lids;
-     struct namelist *lnames;
+GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelist *lnames)
 {
     register afs_int32 code = 0;
     int n = 0;
@@ -413,10 +404,7 @@ GetNameOrId(as, lids, lnames)
 
 
 int
-GetNameOrId(as, lids, lnames)
-     register struct cmd_syndesc *as;
-     struct idlist *lids;
-     struct namelist *lnames;
+GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelist *lnames)
 {
     register afs_int32 code = 0;
     int n = 0, nd = 0, nm = 0, id, x;
@@ -503,8 +491,8 @@ GetNameOrId(as, lids, lnames)
 }
 
 
-AddToGroup(as)
-     register struct cmd_syndesc *as;
+int
+AddToGroup(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     struct cmd_item *u, *g;
@@ -524,8 +512,8 @@ AddToGroup(as)
     return 0;
 }
 
-RemoveFromGroup(as)
-     register struct cmd_syndesc *as;
+int
+RemoveFromGroup(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     struct cmd_item *u, *g;
@@ -545,8 +533,8 @@ RemoveFromGroup(as)
     return 0;
 }
 
-ListMembership(as)
-     register struct cmd_syndesc *as;
+int
+ListMembership(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     idlist ids;
@@ -590,8 +578,8 @@ ListMembership(as)
     return 0;
 }
 
-Delete(as)
-     register struct cmd_syndesc *as;
+int
+Delete(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     idlist ids;
@@ -629,8 +617,8 @@ char *flags_upcase = "SOMA ";	/* legal all access values */
 char *flags_dncase = "s mar";	/* legal member acces values */
 int flags_shift[5] = { 2, 1, 2, 2, 1 };	/* bits for each */
 
-CheckEntry(as)
-     register struct cmd_syndesc *as;
+int
+CheckEntry(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     afs_int32 rcode = 1;
@@ -728,8 +716,8 @@ CheckEntry(as)
     return (rcode);
 }
 
-ListEntries(as)
-     struct cmd_syndesc *as;
+int
+ListEntries(struct cmd_syndesc *as, char *arock)
 {
     afs_int32 code = 0;
     afs_int32 flag, startindex, nentries, nextstartindex;
@@ -765,8 +753,8 @@ ListEntries(as)
     return code;
 }
 
-ChownGroup(as)
-     register struct cmd_syndesc *as;
+int
+ChownGroup(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     char *name;
@@ -781,8 +769,8 @@ ChownGroup(as)
     return code;
 }
 
-ChangeName(as)
-     register struct cmd_syndesc *as;
+int
+ChangeName(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     char *oldname;
@@ -797,8 +785,8 @@ ChangeName(as)
     return code;
 }
 
-ListMax(as)
-     register struct cmd_syndesc *as;
+int
+ListMax(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     afs_int32 maxUser, maxGroup;
@@ -818,8 +806,8 @@ ListMax(as)
     return code;
 }
 
-SetMax(as)
-     register struct cmd_syndesc *as;
+int
+SetMax(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     afs_int32 maxid;
@@ -858,14 +846,14 @@ SetMax(as)
     return code;
 }
 
-SetFields(as)
-     register struct cmd_syndesc *as;
+int
+SetFields(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     idlist ids;
     namelist names;
     int i;
-    afs_int32 mask, flags, ngroups, nusers;
+    afs_int32 mask, flags=0, ngroups, nusers;
 
     if (GetNameOrId(as, &ids, &names))
 	return PRBADARG;
@@ -953,8 +941,8 @@ SetFields(as)
     return 0;
 }
 
-ListOwned(as)
-     register struct cmd_syndesc *as;
+int
+ListOwned(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     idlist ids;
@@ -1004,8 +992,7 @@ ListOwned(as)
 }
 
 static void
-add_std_args(ts)
-     register struct cmd_syndesc *ts;
+add_std_args(register struct cmd_syndesc *ts)
 {
     char test_help[AFSDIR_PATH_MAX];
 
@@ -1031,9 +1018,7 @@ static void add_NameOrId_args (ts)
 #include "AFS_component_version_number.c"
 
 int
-main(argc, argv)
-     int argc;
-     char **argv;
+main(int argc, char **argv)
 {
     register afs_int32 code;
     register struct cmd_syndesc *ts;
@@ -1177,7 +1162,7 @@ main(argc, argv)
 #if defined(SUPERGROUPS)
     finished = 1;
     if (code = cmd_Dispatch(argc, argv)) {
-	CleanUp(0);
+	CleanUp(NULL, NULL);
 	exit(1);
     }
     source = stdin;
@@ -1212,7 +1197,7 @@ main(argc, argv)
 	parsev[0] = savec;
 	cmd_FreeArgv(parsev);
     }
-    CleanUp(0);
+    CleanUp(NULL, NULL);
     exit(0);
 
 #else /* SUPERGROUPS */
